Kumparanian
===========

Kumparanian is a set of workflows that optimize Kumparan’s data
engineering and data scientist hiring process. It’s cut down 1-2 day(s)
submission review process in just less than one hour.
